@@ -11,16 +11,16 @@ fight with finding the right module to use.
 """
 
 __appname__ = "sunlight"
-__version__ = "1.1.6"
+__version__ = "1.1.7"
 
 import sunlight.services.openstates
 import sunlight.services.capitolwords
 import sunlight.services.congress
 import sunlight.services.influenceexplorer
 
-openstates = sunlight.services.openstates.openstates()
-capitolwords = sunlight.services.capitolwords.capitolwords()
-congress = sunlight.services.congress.congress()
+openstates = sunlight.services.openstates.Openstates()
+capitolwords = sunlight.services.capitolwords.CapitolWords()
+congress = sunlight.services.congress.Congress()
 influenceexplorer = sunlight.services.influenceexplorer.InfluenceExplorer()
 
 import os.path
@@ -29,6 +29,15 @@ import sunlight.config
 import sunlight.service
 
 
+def available_services():
+    return {
+        'openstates': openstates,
+        'capitolwords': capitolwords,
+        'congress': congress,
+        'influenceexplorer': influenceexplorer,
+    }
+
+
 def _attempt_to_load_apikey():
     """
     This function (which will be auto-called on import of :mod:`sunlight`),
